Chart gallery
=============

This page shows every public chart type in three documentation modes:

- **Color**: the chart rendered with ANSI color and Unicode enabled
- **Greyscale**: the chart rendered through the same pipeline with ANSI colors
  remapped to a greyscale palette for print and accessibility review
- **Monochrome**: the chart rendered without ANSI color and with ASCII-safe
  characters

The screenshots are generated from the library itself by
``scripts/generate_doc_screenshots.py`` and stored under
``docs/_static/screenshots/``.

BarChart
--------

- **Color**

  .. image:: /_static/screenshots/bar_chart/color.png
     :alt: Color screenshot of the BarChart renderer
     :width: 100%

- **Greyscale**

  .. image:: /_static/screenshots/bar_chart/greyscale.png
     :alt: Greyscale screenshot of the BarChart renderer
     :width: 100%

- **Monochrome**

  .. image:: /_static/screenshots/bar_chart/monochrome.png
     :alt: Monochrome screenshot of the BarChart renderer
     :width: 100%

Histogram
---------

- **Color**

  .. image:: /_static/screenshots/histogram/color.png
     :alt: Color screenshot of the Histogram renderer
     :width: 100%

- **Greyscale**

  .. image:: /_static/screenshots/histogram/greyscale.png
     :alt: Greyscale screenshot of the Histogram renderer
     :width: 100%

- **Monochrome**

  .. image:: /_static/screenshots/histogram/monochrome.png
     :alt: Monochrome screenshot of the Histogram renderer
     :width: 100%

Heatmap
-------

- **Color**

  .. image:: /_static/screenshots/heatmap/color.png
     :alt: Color screenshot of the Heatmap renderer
     :width: 100%

- **Greyscale**

  .. image:: /_static/screenshots/heatmap/greyscale.png
     :alt: Greyscale screenshot of the Heatmap renderer
     :width: 100%

- **Monochrome**

  .. image:: /_static/screenshots/heatmap/monochrome.png
     :alt: Monochrome screenshot of the Heatmap renderer
     :width: 100%

BoxPlot
-------

- **Color**

  .. image:: /_static/screenshots/box_plot/color.png
     :alt: Color screenshot of the BoxPlot renderer
     :width: 100%

- **Greyscale**

  .. image:: /_static/screenshots/box_plot/greyscale.png
     :alt: Greyscale screenshot of the BoxPlot renderer
     :width: 100%

- **Monochrome**

  .. image:: /_static/screenshots/box_plot/monochrome.png
     :alt: Monochrome screenshot of the BoxPlot renderer
     :width: 100%

LineChart
---------

- **Color**

  .. image:: /_static/screenshots/line_chart/color.png
     :alt: Color screenshot of the LineChart renderer
     :width: 100%

- **Greyscale**

  .. image:: /_static/screenshots/line_chart/greyscale.png
     :alt: Greyscale screenshot of the LineChart renderer
     :width: 100%

- **Monochrome**

  .. image:: /_static/screenshots/line_chart/monochrome.png
     :alt: Monochrome screenshot of the LineChart renderer
     :width: 100%

ScatterPlot
-----------

- **Color**

  .. image:: /_static/screenshots/scatter_plot/color.png
     :alt: Color screenshot of the ScatterPlot renderer
     :width: 100%

- **Greyscale**

  .. image:: /_static/screenshots/scatter_plot/greyscale.png
     :alt: Greyscale screenshot of the ScatterPlot renderer
     :width: 100%

- **Monochrome**

  .. image:: /_static/screenshots/scatter_plot/monochrome.png
     :alt: Monochrome screenshot of the ScatterPlot renderer
     :width: 100%

ComparisonBar
-------------

- **Color**

  .. image:: /_static/screenshots/comparison_bar/color.png
     :alt: Color screenshot of the ComparisonBar renderer
     :width: 100%

- **Greyscale**

  .. image:: /_static/screenshots/comparison_bar/greyscale.png
     :alt: Greyscale screenshot of the ComparisonBar renderer
     :width: 100%

- **Monochrome**

  .. image:: /_static/screenshots/comparison_bar/monochrome.png
     :alt: Monochrome screenshot of the ComparisonBar renderer
     :width: 100%

DivergingBar
------------

- **Color**

  .. image:: /_static/screenshots/diverging_bar/color.png
     :alt: Color screenshot of the DivergingBar renderer
     :width: 100%

- **Greyscale**

  .. image:: /_static/screenshots/diverging_bar/greyscale.png
     :alt: Greyscale screenshot of the DivergingBar renderer
     :width: 100%

- **Monochrome**

  .. image:: /_static/screenshots/diverging_bar/monochrome.png
     :alt: Monochrome screenshot of the DivergingBar renderer
     :width: 100%

SummaryBox
----------

- **Color**

  .. image:: /_static/screenshots/summary_box/color.png
     :alt: Color screenshot of the SummaryBox renderer
     :width: 100%

- **Greyscale**

  .. image:: /_static/screenshots/summary_box/greyscale.png
     :alt: Greyscale screenshot of the SummaryBox renderer
     :width: 100%

- **Monochrome**

  .. image:: /_static/screenshots/summary_box/monochrome.png
     :alt: Monochrome screenshot of the SummaryBox renderer
     :width: 100%

PercentileLadder
----------------

- **Color**

  .. image:: /_static/screenshots/percentile_ladder/color.png
     :alt: Color screenshot of the PercentileLadder renderer
     :width: 100%

- **Greyscale**

  .. image:: /_static/screenshots/percentile_ladder/greyscale.png
     :alt: Greyscale screenshot of the PercentileLadder renderer
     :width: 100%

- **Monochrome**

  .. image:: /_static/screenshots/percentile_ladder/monochrome.png
     :alt: Monochrome screenshot of the PercentileLadder renderer
     :width: 100%

NormalizedSpeedup
-----------------

- **Color**

  .. image:: /_static/screenshots/normalized_speedup/color.png
     :alt: Color screenshot of the NormalizedSpeedup renderer
     :width: 100%

- **Greyscale**

  .. image:: /_static/screenshots/normalized_speedup/greyscale.png
     :alt: Greyscale screenshot of the NormalizedSpeedup renderer
     :width: 100%

- **Monochrome**

  .. image:: /_static/screenshots/normalized_speedup/monochrome.png
     :alt: Monochrome screenshot of the NormalizedSpeedup renderer
     :width: 100%

StackedBar
----------

- **Color**

  .. image:: /_static/screenshots/stacked_bar/color.png
     :alt: Color screenshot of the StackedBar renderer
     :width: 100%

- **Greyscale**

  .. image:: /_static/screenshots/stacked_bar/greyscale.png
     :alt: Greyscale screenshot of the StackedBar renderer
     :width: 100%

- **Monochrome**

  .. image:: /_static/screenshots/stacked_bar/monochrome.png
     :alt: Monochrome screenshot of the StackedBar renderer
     :width: 100%

SparklineTable
--------------

- **Color**

  .. image:: /_static/screenshots/sparkline_table/color.png
     :alt: Color screenshot of the SparklineTable renderer
     :width: 100%

- **Greyscale**

  .. image:: /_static/screenshots/sparkline_table/greyscale.png
     :alt: Greyscale screenshot of the SparklineTable renderer
     :width: 100%

- **Monochrome**

  .. image:: /_static/screenshots/sparkline_table/monochrome.png
     :alt: Monochrome screenshot of the SparklineTable renderer
     :width: 100%

CDFChart
--------

- **Color**

  .. image:: /_static/screenshots/cdf_chart/color.png
     :alt: Color screenshot of the CDFChart renderer
     :width: 100%

- **Greyscale**

  .. image:: /_static/screenshots/cdf_chart/greyscale.png
     :alt: Greyscale screenshot of the CDFChart renderer
     :width: 100%

- **Monochrome**

  .. image:: /_static/screenshots/cdf_chart/monochrome.png
     :alt: Monochrome screenshot of the CDFChart renderer
     :width: 100%

RankTable
---------

- **Color**

  .. image:: /_static/screenshots/rank_table/color.png
     :alt: Color screenshot of the RankTable renderer
     :width: 100%

- **Greyscale**

  .. image:: /_static/screenshots/rank_table/greyscale.png
     :alt: Greyscale screenshot of the RankTable renderer
     :width: 100%

- **Monochrome**

  .. image:: /_static/screenshots/rank_table/monochrome.png
     :alt: Monochrome screenshot of the RankTable renderer
     :width: 100%
